<?php
/**
 * @file
 * Contain \Drupal\quran\Controller\QuranController.
 */

namespace Drupal\quran\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;
use Drupal\Core\Link;

class QuranController extends ControllerBase {
  const QURAN_FILE = 'quran-uthmani.txt';   // quran file
  const META_DATA_FILE = 'quran-data.xml';   // quran metadata file
  const TRANS_FILE = 'id.indonesian.txt';  // translation file

  protected $surahData;

  public function __construct() {
    $dataItems = [
      "index",
      "start",
      "ayas",
      "name",
      "tname",
      "ename",
      "type",
      "rukus",
    ];

    $quranData = file_get_contents(drupal_get_path('module', 'quran') . '/src/' . self::META_DATA_FILE);

    $parser = xml_parser_create();
    xml_parse_into_struct($parser, $quranData, $values, $index);
    xml_parser_free($parser);

    $rows = [];

    $surahData = array();

    for ($i = 1; $i <= 114; $i++) {
      $j = $index['SURA'][$i - 1];
      foreach ($dataItems as $item) {
        $surahData[$i][$item] = $values[$j]['attributes'][strtoupper($item)];
      }

    }
    $this->surahData = $surahData;
  }

  function getSurahData($surah, $property) {
    return $this->surahData[$surah][$property];
  }

  function getSurahAllData($surah) {
    return $this->surahData[$surah];
  }

  function getSurahContents($surah) {
    $startAya = $this->getSurahData($surah, 'start');
    $endAya = $startAya + $this->getSurahData($surah, 'ayas');
    $quranFile = drupal_get_path('module', 'quran') . '/src/' . self::QURAN_FILE;
    $quran = file($quranFile);
    $text = array_slice($quran, $startAya, $endAya - $startAya);
    return $text;
  }

  function getSurahTrans($surah, $lang) {
    $langFile = [
      'id' => 'id.indonesian.txt',
      'en' => 'en.yusufali.txt',
    ];

    if (!array_key_exists($lang, $langFile)) {
      $lang = 'en';
    }

    $transText = $langFile[$lang];

    $startAya = $this->getSurahData($surah, 'start');
    $endAya = $startAya + $this->getSurahData($surah, 'ayas');
    $quranFile = drupal_get_path('module', 'quran') . '/src/' . $transText;
    $quran = file($quranFile);
    $text = array_slice($quran, $startAya, $endAya - $startAya);
    return $text;
  }

  public function content() {

    foreach ($this->surahData as $index => $data) {
      // Normally we would add some nice formatting to our rows
      // but for our purpose we are simply going to add our row
      // to the array.
      $url = Url::fromRoute('quran_surah', ['surah' => $index]);
      $rows[] = [
        $index,
        Link::fromTextAndUrl($data['tname'] . ' (' . $data['ename'] . ')', $url),
        $data['ayas'],
        $data['type'],
      ];
    }

    $table = [
      '#theme' => 'table',
      '#header' => [
        $this->t('No.'),
        $this->t('Surah'),
        $this->t('Verses'),
        $this->t('Place of Revelation'),
      ],
      '#rows' => $rows,
    ];

    return [
      '#theme' => 'table',
      '#header' => [
        $this->t('No.'),
        $this->t('Surah'),
        $this->t('Verses'),
        $this->t('Place of Revelation'),
      ],
      '#rows' => $rows,
    ];
  }

  public function surah($surah) {
    $request = \Drupal::request();
    $lang = $request->query->get('trans');

    if (is_null($lang)) $lang = 'en';

    $surahText = $this->getSurahContents($surah);
    $transText = $this->getSurahTrans($surah, $lang);

    $data = $this->getSurahAllData($surah);

    $showBismillah = FALSE; // change to true to show Bismillahs
    $ayaNum = 0;

    foreach ($surahText as $index => $aya) {
      // remove bismillahs, except for suras 1 and 9
      if (!$showBismillah && $ayaNum == 0 && $surah != 1 && $surah != 9) {
        $aya = preg_replace('/^(([^ ]+ ){4})/u', '', $aya);
      }
      $rows[$ayaNum]['aya'] = $index + 1;
      $rows[$ayaNum]['text']['data'] = $aya;
      $rows[$ayaNum]['text']['class'] = 'quran-text';
      $ayaNum++;
      $rows[$ayaNum]['aya'] = '';
      $rows[$ayaNum]['text'] = $transText[$index];
      $ayaNum++;
    }

    $build['#change_form'] = \Drupal::formBuilder()
      ->getForm('Drupal\quran\Form\SurahForm');

    $build['#surah_content'] = [
      '#theme' => 'table',
      '#rows' => $rows,
    ];

    $build['#data'] = $data;
    $build['#lang'] = $lang;

    $build['#attached']['library'][] = 'quran/quran.surah';
    $build['#theme'] = 'quran_surah';

    return $build;

  }
}