<?php

/**
 * @file
 * Contains Drupal\quran\Form\SurahForm.
 */

namespace Drupal\quran\Form;


use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the SurahForm form controller.
 *
 * Add selector for quran translation
 *
 * @see \Drupal\Core\Form\FormBase
 */
class SurahForm extends FormBase {

  /**
   * Build the simple form.
   *
   * A build form method constructs an array that defines how markup and
   * other form elements are included in an HTML form.
   *
   * @param array $form
   *   Default form array structure.
   * @param FormStateInterface $form_state
   *   Object containing current form state.
   *
   * @return array
   *   The render array defining the elements of the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $request = \Drupal::request();
    $lang = $request->query->get('trans');

    if (is_null($lang)) $lang = 'en';

    $form['trans'] = [
      '#title' => $this->t('Translation'),
      '#type' => 'select',
      '#options' => [
        'en' => 'English - Yusuf Ali',
        'id' => 'Bahasa Indonesia - Departemen Agama',
      ],
      '#default_value' => $lang,
      '#attributes' => array('class' => array('form--inline')),
    ];

    $form['actions'] = [
      '#type' => 'actions',
    ];

    // Add a submit button that handles the submission of the form.
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
      '#attributes' => array('class' => array('form--inline')),
    ];

    return $form;
  }

  /**
   * Getter method for Form ID.
   *
   * The form ID is used in implementations of hook_form_alter() to allow other
   * modules to alter the render array built by this form controller.  it must
   * be unique site wide. It normally starts with the providing module's name.
   *
   * @return string
   *   The unique ID of the form defined by this class.
   */
  public function getFormId() {
    return 'quran_surah_form';
  }

  /**
   * Implements form validation.
   *
   * The validateForm method is the default method called to validate input on
   * a form.
   *
   * @param array $form
   *   The render array of the currently built form.
   * @param FormStateInterface $form_state
   *   Object describing the current state of the form.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
  }

  /**
   * Implements a form submit handler.
   *
   * The submitForm method is the default method called for any submit elements.
   *
   * @param array $form
   *   The render array of the currently built form.
   * @param FormStateInterface $form_state
   *   Object describing the current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $surah = \Drupal::routeMatch()->getParameter('surah');
    
    $form_state->setRedirect('quran_surah',
      array('surah' => $surah),
      array(
        'query' => array(
          'trans' => $form_state->getValue('trans'),
        ),
      )
    );
  }

}